<?php
/**
 * Plugin Name: Motorsports Calendar Widget
 * Plugin URI: https://wordpress.org/plugins/motorsports-calendar/
 * Description: Add customizable countdown widgets for various motorsport series including Formula 1, MotoGP, WEC, NASCAR, and more.
 * Version: 1.0.0
 * Requires at least: 5.2
 * Requires PHP: 7.2
 * Author: QBased
 * Author URI: https://qbased.group/
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: motorsports-calendar-widget
 * Domain Path: /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
    die;
}

// Define plugin constants
if ( ! defined( 'MOTOCALWID_VERSION' ) ) {
    define( 'MOTOCALWID_VERSION', '1.0.0' );
}
if ( ! defined( 'MOTOCALWID_PLUGIN_DIR' ) ) {
    define( 'MOTOCALWID_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
}
if ( ! defined( 'MOTOCALWID_PLUGIN_URL' ) ) {
    define( 'MOTOCALWID_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
}
if ( ! defined( 'MOTOCALWID_PLUGIN_BASENAME' ) ) {
    define( 'MOTOCALWID_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
}

/**
 * Initialize the plugin
 *
 * @since 1.0.0
 */
function motocalwid_init() {
	// Load text domain for internationalization
    load_plugin_textdomain(
        'motorsports-calendar-widget',
        false,
        dirname( MOTOCALWID_PLUGIN_BASENAME ) . '/languages'
    );
}
add_action( 'plugins_loaded', 'motocalwid_init' );

/**
 * Register the widget
 *
 * @since 1.0.0
 */
function motocalwid_register_widget() {
    require_once MOTOCALWID_PLUGIN_DIR . 'includes/class-motorsports-calendar-widget.php';
    register_widget( 'Motocalwid_Widget' );
}
add_action( 'widgets_init', 'motocalwid_register_widget' );

/**
 * Activation hook callback
 *
 * @since 1.0.0
 */
function motocalwid_activate() {
    // Add options or create necessary database tables
    add_option( 'motocalwid_version', MOTOCALWID_VERSION );
    
    // Ensure includes directory exists
    $includes_dir = plugin_dir_path( __FILE__ ) . 'includes';
    if ( ! file_exists( $includes_dir ) ) {
        wp_mkdir_p( $includes_dir );
    }
    
    // Clear the permalinks
    flush_rewrite_rules();
}
register_activation_hook( __FILE__, 'motocalwid_activate' );

/**
 * Deactivation hook callback
 *
 * @since 1.0.0
 */
function motocalwid_deactivate() {
    // Clean up any plugin-specific options or data if needed
    
    // Clear the permalinks
    flush_rewrite_rules();
}
register_deactivation_hook( __FILE__, 'motocalwid_deactivate' );

/**
 * Uninstall hook callback - handled in uninstall.php
 */